@@ -908,6 +908,7 @@ bluez_appeared_cb (GDBusConnection *connection,
 	while ((v = g_variant_iter_next_value (&iter))) {
 		g_variant_get (v, "{o*}", &key, &ifaces);
 		interface_added (client, key, ifaces);
+		g_free (key);
 	}
 
 	g_variant_unref (variant);
@@ -1094,7 +1095,7 @@ _bluetooth_client_set_discoverable (BluetoothClient *client,
 	if (ret == FALSE) {
 		g_warning ("Failed to set Discoverable to %d: %s", discoverable, error->message);
 		g_error_free (error);
-	} else {
+	} else if (discoverable) {
 		ret = properties_call_set_sync (properties,
 						BLUEZ_ADAPTER_INTERFACE,
 						"DiscoverableTimeout",
