@@ -254,10 +254,20 @@ text_changed_cb (GObject    *gobject,
 static void
 bluetooth_pairing_dialog_init (BluetoothPairingDialog *self)
 {
+	GtkCssProvider *provider;
+
 	gtk_widget_init_template (GTK_WIDGET (self));
 
 	gtk_widget_set_size_request (GTK_WIDGET (self), 380, -1);
 	gtk_window_set_resizable (GTK_WINDOW (self), FALSE);
+
+	provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_resource (provider, "/org/gnome/bluetooth/bluetooth-settings.css");
+	gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+						   GTK_STYLE_PROVIDER (provider),
+						   GTK_STYLE_PROVIDER_PRIORITY_USER);
+	g_object_unref (provider);
+
 }
 
 static void
@@ -272,6 +282,8 @@ bluetooth_pairing_dialog_constructed (GObject *object)
 	header = gtk_dialog_get_header_bar (GTK_DIALOG (self));
 	priv->title = gtk_label_new ("");
 	gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header), priv->title);
+	gtk_widget_show (priv->title);
+	gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header), FALSE);
 
 	/* OK button */
 	priv->done = gtk_button_new_with_label (_("Accept"));
