@@ -44,6 +44,11 @@ bluetooth_type_get_type (void)
       { BLUETOOTH_TYPE_JOYPAD, "BLUETOOTH_TYPE_JOYPAD", "joypad" },
       { BLUETOOTH_TYPE_TABLET, "BLUETOOTH_TYPE_TABLET", "tablet" },
       { BLUETOOTH_TYPE_VIDEO, "BLUETOOTH_TYPE_VIDEO", "video" },
+      { BLUETOOTH_TYPE_REMOTE_CONTROL, "BLUETOOTH_TYPE_REMOTE_CONTROL", "remote-control" },
+      { BLUETOOTH_TYPE_SCANNER, "BLUETOOTH_TYPE_SCANNER", "scanner" },
+      { BLUETOOTH_TYPE_DISPLAY, "BLUETOOTH_TYPE_DISPLAY", "display" },
+      { BLUETOOTH_TYPE_WEARABLE, "BLUETOOTH_TYPE_WEARABLE", "wearable" },
+      { BLUETOOTH_TYPE_TOY, "BLUETOOTH_TYPE_TOY", "toy" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("BluetoothType", values);
